/**
 * Check if a value is a string at runtime.
 * @param str
 * @returns
 */
declare const isString: (str: any) => boolean;
/**
 * Checks if a string is an ASCII printable string.
 */
declare const isAsciiPrintableString: (str: string) => boolean;
/**
 * check for ascii printable alphanumeric symbols only
 */
declare const isAsciiPrintableSpaceAlphanumericSymbolsString: (str: string) => boolean;
/**
 * check if a string contains alphanumeric or underscore
 */
declare const isAlphaNumericUnderscoreSpaceString: (str: string) => boolean;
/**
 * check if a string contains alphanumeric, underscore, and period only.
 */
declare const isAlphaNumericUnderscorePeriodString: (str: string) => boolean;
/**
 * check if a string contains alphanumeric, underscore, or commas.
 */
declare const isAlphaNumericUnderscoreSpaceCommaString: (str: string) => boolean;
/**
 * check if a string contains alphanumeric, underscore, period, or commas.
 */
declare const isAlphaNumericUnderscoreSpaceCommaPeriodString: (str: string) => boolean;
/**
 * check if a string contains alphanumeric or underscore
 */
declare const isAlphaNumericUnderscoreString: (str: string) => boolean;
/**
 * check if a string contains alphanumeric, underscore, or dashes
 */
declare const isAlphaNumericUnderscoreDashString: (str: string) => boolean;
/**
 * check if a string contains alphanumeric values
 */
declare const isAlphaNumericString: (str: string) => boolean;
/**
 * check if a string contains only numeric values
 */
declare const isNumericString: (str: string) => boolean;
/**
 * Check if a string contains alphabet characters only.
 */
declare const isAlphabetString: (str: string) => boolean;
/**
 * check if a string contains only hexidecimal values
 */
declare const isHexString: (str: string) => boolean;
/**
 * searches a string for disallowed characters
 */
declare const findDisallowedCharactersInString: (str: string, allowed_chars: string[]) => string[] | null;
/**
 * This is used for breaking up strings along non-ascii deliniations, and is used
 * mostly for parsing unstructured or unusual text.
 */
declare const splitOnFirstNonAsciiPrintableChar: (str: string) => string[] | null;
/**
 * simply removes any leading whitespace from a line
 * @param str
 * @returns
 */
declare const stripLeadingWhitespaceFromString: (str: string) => string;
/**
 * removes the first instance of a string from a string and returns
 * the modified string.  Does not use regular expressions.
 */
declare const removeFirstInstanceFromString: (str: string, search: string) => string;
/**
 * This will examine a string and remove any repeating characters.  This is mostly
 * used for analyzing and parsing unstructured text.  Does not use regular expressions.
 * @param val
 * @returns
 */
declare const removeRepeatingCharactersFromString: (val: string) => string;
/**
 * remove the last character in a string
 */
declare const rtrim: (str: string) => string;
/**
 * remove the first character in a string
 */
declare const ltrim: (str: string) => string;
/**
 * check if value is a uuid
 */
declare const isValidUUIDString: (uuid_val: string) => boolean;
/**
 * check if value is a double length uuid
 */
declare const isValidDoubleLengthUUIDString: (double_length_uuid_val: string) => boolean;
/**
 * sort integer string array (parses to in, then sorts by string)
 */
declare const sortIntegerStringArray: (int_string_array: string[]) => string[] | null;
/**
 * Take an array of strings, remove any non-alphanumeric characters, sort
 * the strings alphabetically, and remove any duplicates.
 */
declare const sortAndDeduplicateAlphanumericStringArray: (str_array: string[]) => string[] | null;
/**
 * Take a string, tokenize it, and return an array of strings.  Options include sorting, deduplicating, and converting to lowercase.
 */
declare const tokenizeString: (params: {
    input_string: string;
    options?: {
        sort?: boolean;
        deduplicate?: boolean;
        to_lowercase?: boolean;
    };
}) => string[] | null;
/**
 * capitalizes words in a string
 */
declare const capitalizeWords: (str: string, separator?: string) => string | null;
/**
 * Convert a string to lowercase with underscores
 */
declare const stringToLowercaseUnderscore: (str_to_convert: string) => string;
declare const stringToNormalizedLowercaseNoSpecialChars: (params: {
    input_string: string;
    options?: {
        to_lowercase?: boolean;
        join_str?: string;
    };
}) => string | null;
/**
 * convert a string to an array of hex strings (each entry is 0x00-0xff)
 */
declare const stringToHexArray: (input_string: string) => string[];
/**
 * check if a string ends with a specific string
 */
declare const stringEndsWith: (str: string, ends_with: string) => boolean;
/**
 * check if string ends with item in array
 */
declare const stringEndsWithItemInArray: (str: string, array_of_end_items: string[]) => boolean;
/**
 * check if a string starts with a specific string
 */
declare const stringStartsWith: (str: string, starts_with: string) => boolean;
/**
 * check if string starts with item in array
 */
declare const stringStartsWithItemInArray: (str: string, array_of_start_items: string[]) => boolean;
/**
 * remove newlines from string
 */
declare const stringRemoveNewlines: (str: string) => string;
/**
 * remove last line from string
 */
declare const removeLastLineFromString: (str: string, char?: string) => string;
/**
 * This utility is used for removing the "front part" from matching strings.
 */
declare const removeCommonFrontPartsFromStringArray: (strings: string[]) => string[];
/**
 * simply returns a joined representation of a string array.
 */
declare const stringArrayToString: (string_array: string[], seperator: string) => string | null;
/**
 * split a string by length by inserting a replacement character
 */
declare const splitStringByLength: (string: string, length: number, replacement?: string) => string;

export { capitalizeWords, findDisallowedCharactersInString, isAlphaNumericString, isAlphaNumericUnderscoreDashString, isAlphaNumericUnderscorePeriodString, isAlphaNumericUnderscoreSpaceCommaPeriodString, isAlphaNumericUnderscoreSpaceCommaString, isAlphaNumericUnderscoreSpaceString, isAlphaNumericUnderscoreString, isAlphabetString, isAsciiPrintableSpaceAlphanumericSymbolsString, isAsciiPrintableString, isHexString, isNumericString, isString, isValidDoubleLengthUUIDString, isValidUUIDString, ltrim, removeCommonFrontPartsFromStringArray, removeFirstInstanceFromString, removeLastLineFromString, removeRepeatingCharactersFromString, rtrim, sortAndDeduplicateAlphanumericStringArray, sortIntegerStringArray, splitOnFirstNonAsciiPrintableChar, splitStringByLength, stringArrayToString, stringEndsWith, stringEndsWithItemInArray, stringRemoveNewlines, stringStartsWith, stringStartsWithItemInArray, stringToHexArray, stringToLowercaseUnderscore, stringToNormalizedLowercaseNoSpecialChars, stripLeadingWhitespaceFromString, tokenizeString };
